# Authors

## Original author

Dug Song \<<dugsong@monkey.org>\>

## Contributors

  - Timur Alperovich \<<timuralp@umich.edu>\>  
    radiotap module

  - Nic Bellamy \<<nic.bellamy@vadacom.co.nz>\>  
    HTTP header parsing fix

  - the grugq \<<thegrugq@gmail.com>\>  
    better RTP module

  - David Helder \<<dhelder@gizmolabs.org>\>  
    bug fixes

  - Przemyslaw Karwasiecki \<<karwas@gmail.com>\>  
    TABLE\_DUMP in MRT module

  - Reza Lotun \<<rlotun@cs.ubc.ca>\>  
    MetaPacket cleanup

  - Jeff Nathan \<<jeff@snort.org>\>  
    bug fixes

  - Tim Newsham \<<newsham@lava.net>\>  
    IPv6 bugfixing and improvements

  - <keisuke.nishimoto@gmail.com>  
    Snoop file parser

  - Jon Oberheide \<<jon@oberheide.org>\>  
    STUN, H.225, TPKT, NTP, RIP, Diameter, SCTP, BGP, MRT, RX modules

  - <plotnikoff@gmail.com>  
    handle dynamic imports from py2exe/freeze.py/zipped egg packages

  - <simdream@gmail.com>  
    handle multiple cookie values in HTTP

  - Owen Stephens \<<owen@owenstephens.co.uk>\>  
    IP6 extension header support

  - Robert Stone \<<otaku@monkey.org>\>  
    Netflow and QQ modules

  - Thomas Taranowski \<<thomastaranowski@yahoo.com>\>  
    dnet IP checksum bug on i386

  - Jirka Vejrazka  
    bug fixes

  - Tim Yardley \<<yardley@gmail.com>\>  
    DHCP definitions

  - Oscar Ibatullin \<<oscar.ibatullin@gmail.com>\>  
    pcapng module, core improvements, bit fields, pretty print, creating
    parsers doc

  - Kyle Keppler \<<kyle.keppler@gmail.com>\>  
    Python 3 port

  - Hao Sun \<<sunhao2013@gmail.com>\>  
    Python 3 port

  - Brian Wylie \<<briford.wylie@gmail.com>\>  
    Examples, Docs, Tests, CI, Python 3 port

  - crocogorical \<<crocogorical@gmail.com>\>  
    Extend test coverage

If you want to contribute to dpkt, see `contributing`.
